Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Database ¶
type Database interface {
tes.TaskServiceServer
events.EventServiceServer
pbs.SchedulerServiceServer
WithComputeBackend(compute.Backend)
Init(context.Context) error
}
Database represents the interface to the database used by the scheduler, scaler, etc. Mostly, this exists so it can be mocked during testing.
type Server ¶
type Server struct {
RPCAddress string
HTTPPort string
Password string
TaskServiceServer tes.TaskServiceServer
EventServiceServer events.EventServiceServer
SchedulerServiceServer pbs.SchedulerServiceServer
DisableHTTPCache bool
DialOptions []grpc.DialOption
Log *logger.Logger
}
Server represents a Funnel server. The server handles RPC traffic via gRPC, HTTP traffic for the TES API, and also serves the web dashboard.
func DefaultServer ¶
DefaultServer returns a new server instance.
Click to show internal directories.
Click to hide internal directories.